@@ -217,12 +217,15 @@ class Obraz(Mail_sender):
 
       self._wholebook = [sent[1:3] for sent in csv_book.values]
       for i in range(len(self._wholebook)):
-        self._wholebook[i][0] = re.sub(r'<.*?>', '', self._wholebook[i][0])
-        self._wholebook[i][0] = re.sub(r'[\n\t]', '', self._wholebook[i][0])
-        self._wholebook[i][0] = self._wholebook[i][0].strip()
-        self._wholebook[i][1] = re.sub(r'<.*?>', '', self._wholebook[i][1])
-        self._wholebook[i][1] = re.sub(r'[\n\t]', '', self._wholebook[i][1])
-        self._wholebook[i][1] = self._wholebook[i][1].strip()
+        if type(self._wholebook[i][0]) != type(148.97):
+          self._wholebook[i][0] = re.sub(r'<.*?>', '', self._wholebook[i][0])
+          self._wholebook[i][0] = re.sub(r'[\n\t]', '', self._wholebook[i][0])
+          self._wholebook[i][0] = self._wholebook[i][0].strip()
+          self._wholebook[i][1] = re.sub(r'<.*?>', '', self._wholebook[i][1])
+          self._wholebook[i][1] = re.sub(r'[\n\t]', '', self._wholebook[i][1])
+          self._wholebook[i][1] = self._wholebook[i][1].strip()
+        else:
+          self._wholebook[i][0] = "пустое место"
       self.book = self._wholebook
 
     elif adress_book != None:
@@ -230,13 +233,15 @@ class Obraz(Mail_sender):
 
       self._wholebook = [sent[1:3] for sent in csv_book.values]
       for i in range(len(self._wholebook)):
-        self._wholebook[i][0] = re.sub(r'<.*?>', '', self._wholebook[i][0])
-        self._wholebook[i][0] = re.sub(r'[\n\t]', '', self._wholebook[i][0])
-        self._wholebook[i][0] = self._wholebook[i][0].strip()
-        self._wholebook[i][1] = re.sub(r'<.*?>', '', self._wholebook[i][1])
-        self._wholebook[i][1] = re.sub(r'[\n\t]', '', self._wholebook[i][1])
-        self._wholebook[i][1] = self._wholebook[i][1].strip()
-      self.book = self._wholebook
+        if type(self._wholebook[i][0]) != type(148.97):
+          self._wholebook[i][0] = re.sub(r'<.*?>', '', self._wholebook[i][0])
+          self._wholebook[i][0] = re.sub(r'[\n\t]', '', self._wholebook[i][0])
+          self._wholebook[i][0] = self._wholebook[i][0].strip()
+          self._wholebook[i][1] = re.sub(r'<.*?>', '', self._wholebook[i][1])
+          self._wholebook[i][1] = re.sub(r'[\n\t]', '', self._wholebook[i][1])
+          self._wholebook[i][1] = self._wholebook[i][1].strip()
+        else:
+          self._wholebook[i][0] = "пустое место"
       # print(self.book[:100])
 
   def send_to_email(self, email=None):
